---
title: 결제수단별 취소가능한 기한
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제취소/환불
seo:
  title: 결제수단별 취소가능한 기한
  description: 카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제, 카카오페이, 네이버페이, 페이팔의 결제 취소가 가능한 기한에 대한 정보입니다.
  keywords:
    - 일반결제
tags:
  - 공통
  - 결제취소-환불
pgCompanies:
  - 공통
searchTags:
  - 결제취소
  - 취소가능기한
  - 취소가능기간
  - 취소기한
  - 취소기간
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="결제 취소가 가능한 기한을 안내드립니다.
결제수단별로 다르게 적용되며 결제대행사 및 카드사에 따라 적용되는 기준이 상이할 수 있습니다.
시스템상 환불이 불가한 결제수단의 경우 고객사에 선에서 직접 고객에게 별도 환불 처리를 해 주셔야 하는 점 참고해 주시기 바랍니다." />

### **일반결제**

#### **카드**

- 환불 수수료 : 없음
- 환불 가능 기한 : 보통 1년(카드사별로 예외적으로 3개월로 제한되는 곳도 있으니 카드사 확인이 필요합니다)
- KSNET의 경우 최대 6개월까지 취소 가능

#### **가상 계좌**

- 환불 수수료 : 건당 300원 과금(수수료 발생)
- 환불가능기한 : 기간 제한 없음

#### **실시간 계좌이체**

- 환불 가능 기한 : 약 3개월

#### **휴대폰 소액결제**

- 환불 가능 기한 : 당월 거래건만 취소 가능 (수수료X)
  당월 이후 거래건은 PG사측과 별도로 자체적으로 취소 요청을 해 야합니다.
  (금액이 납부 완료된 상태일 경우, 취소 요청해도 PG사에서 취소 처리가 불가하며, 자체 환불 처리해야 합니다.)
  - 참고사항 : 부분취소 → 휴대폰 결제는 부분취소가 불가합니다.
    - KCP : 별도 설정 후 가능
    - KG이니시스 : 남은 금액 재 승인 후 이전 거래 전체 취소하여 부분 취소 가능

### **결제대행사별 적용 기준**

#### **카카오페이**

- 환불 가능 기한 : 카드 1년이내 / 머니 5년이내 (수수료X)

#### **네이버페이**

- 환불 가능 기한 : 결제일(0일로 정의) 기준, +1095일까지만 취소 가능(수수료X)\
  (2023.11.29 부로, 기존 “+730일까지”에서 변경 됨)

#### **페이팔**

- 환불 가능 기한 : 180일 이내 (수수료X)
  - 참고사항 : 180일의 기준은 페이팔로 \[취소하기 버튼]은 구매자 쪽에 없기 때문에 반드시 판매자의 동의가 있어야만 취소를 구매자가 받을 수 있습니다. \
    판매자가 응답이 없을 경우 구매자는 페이팔이 구매자 보호가 있기 때문에 분쟁을 접수할 수 있고 분쟁 접수할 수 있는 기한이 최대 180일이기 때문에, 최장 180일로 보시면 됩니다.
